@@ -1,35 +1,36 @@
-import datetime
 import enum
 import importlib
 import json
 import logging
 import os
-import sys
 import platform
+import sys
 import uuid
 
 import click
 
 import great_expectations.exceptions as ge_exceptions
-from great_expectations.util import verify_dynamic_loading_support
 from great_expectations import DataContext, rtd_url_ge_version
 from great_expectations.cli.docs import build_docs
 from great_expectations.cli.init_messages import NO_DATASOURCES_FOUND
 from great_expectations.cli.util import (
     cli_message,
-    cli_message_list,
-    cli_message_dict)
+    cli_message_dict,
+    load_data_context_with_error_handling,
+)
+from great_expectations.cli.mark import Mark as mark
 from great_expectations.core import ExpectationSuite
-from great_expectations.core.usage_statistics.usage_statistics import send_usage_message
-from great_expectations.data_context.types.resource_identifiers import (
-    ValidationResultIdentifier,
+from great_expectations.core.usage_statistics.usage_statistics import (
+    send_usage_message,
 )
 from great_expectations.datasource import (
     PandasDatasource,
     SparkDFDatasource,
     SqlAlchemyDatasource,
 )
-from great_expectations.datasource.batch_kwargs_generator import ManualBatchKwargsGenerator
+from great_expectations.datasource.batch_kwargs_generator import (
+    ManualBatchKwargsGenerator,
+)
 from great_expectations.datasource.batch_kwargs_generator.table_batch_kwargs_generator import (
     TableBatchKwargsGenerator,
 )
@@ -37,12 +38,8 @@ from great_expectations.exceptions import (
     BatchKwargsError,
     DatasourceInitializationError,
 )
-from great_expectations.profile.basic_suite_builder_profiler import (
-    BasicSuiteBuilderProfiler,
-)
 from great_expectations.validator.validator import Validator
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -87,12 +84,7 @@ def datasource():
 )
 def datasource_new(directory):
     """Add a new datasource to the data context."""
-    try:
-        context = DataContext(directory)
-    except ge_exceptions.ConfigNotFoundError as err:
-        cli_message("<red>{}</red>".format(err.message))
-        return
-
+    context = load_data_context_with_error_handling(directory)
     datasource_name, data_source_type = add_datasource(context)
 
     if datasource_name:
@@ -120,46 +112,29 @@ def datasource_new(directory):
 )
 def datasource_list(directory):
     """List known datasources."""
-    context = None
-    try:
-        failed = True
-        context = DataContext(directory)
-        datasources = context.list_datasources()
+    context = load_data_context_with_error_handling(directory)
+    datasources = context.list_datasources()
+    datasource_count = len(datasources)
 
-        if len(datasources) == 0:
-            cli_message("No Datasources found")
-            failed=False
-            send_usage_message(
-                data_context=context,
-                event="cli.datasource.list",
-                success=True
-            )
-            return
+    if datasource_count == 0:
+        list_intro_string = "No Datasources found"
+    else:
+        list_intro_string = _build_datasource_intro_string(datasource_count)
 
-        if len(datasources) == 1:
-            list_intro_string = "1 Datasource found:"
+    cli_message(list_intro_string)
+    for datasource in datasources:
+        cli_message("")
+        cli_message_dict(datasource)
 
-        if len(datasources) > 1:
-            list_intro_string = "{} Datasources found:".format(len(datasources))
-        cli_message(list_intro_string)
-        for datasource in datasources:
-            cli_message("")
-            cli_message_dict(datasource)
-        failed = False
-        send_usage_message(
-            data_context=context,
-            event="cli.datasource.list",
-            success=True
-        )
-    except (ge_exceptions.ConfigNotFoundError, ge_exceptions.InvalidConfigError) as err:
-        cli_message("<red>{}</red>".format(err.message))
-    finally:
-        if failed and context is not None:
-            send_usage_message(
-                data_context=context,
-                event="cli.datasource.list",
-                success=False
-            )
+    send_usage_message(data_context=context, event="cli.datasource.list", success=True)
+
+
+def _build_datasource_intro_string(datasource_count):
+    if datasource_count == 1:
+        list_intro_string = "1 Datasource found:"
+    if datasource_count > 1:
+        list_intro_string = f"{datasource_count} Datasources found:"
+    return list_intro_string
 
 
 @datasource.command(name="profile")
@@ -189,21 +164,17 @@ def datasource_list(directory):
 )
 @click.option('--additional-batch-kwargs', default=None,
               help='Additional keyword arguments to be provided to get_batch when loading the data asset. Must be a valid JSON dictionary')
+@mark.cli_as_experimental
 def datasource_profile(datasource, batch_kwargs_generator_name, data_assets, profile_all_data_assets, directory, view, additional_batch_kwargs):
     """
-    Profile a datasource (Beta)
+    Profile a datasource (Experimental)
 
     If the optional data_assets and profile_all_data_assets arguments are not specified, the profiler will check
     if the number of data assets in the datasource exceeds the internally defined limit. If it does, it will
     prompt the user to either specify the list of data assets to profile or to profile all.
     If the limit is not exceeded, the profiler will profile all data assets in the datasource.
     """
-    cli_message("<yellow>Warning - this is a BETA feature.</yellow>")
-    try:
-        context = DataContext(directory)
-    except ge_exceptions.ConfigNotFoundError as err:
-        cli_message("<red>{}</red>".format(err.message))
-        return
+    context = load_data_context_with_error_handling(directory)
 
     try:
         if additional_batch_kwargs is not None:
@@ -481,7 +452,7 @@ def _add_sqlalchemy_datasource(context, prompt_for_datasource_name=True):
         except DatasourceInitializationError as de:
             cli_message(message.format(str(de)))
             if not click.confirm(
-                    "Enter the credentials again?".format(str(de)),
+                    "Enter the credentials again?",
                     default=True
             ):
                 context.add_datasource(datasource_name,
@@ -715,6 +686,7 @@ def _add_spark_datasource(context, passthrough_generator_only=True, prompt_for_d
     return datasource_name
 
 
+# TODO consolidate all the myriad CLI tests into this
 def select_datasource(context, datasource_name=None):
     msg_prompt_select_data_source = "Select a datasource"
     msg_no_datasources_configured = "<red>No datasources found in the context. To add a datasource, run `great_expectations datasource new`</red>"
@@ -742,8 +714,9 @@ def select_datasource(context, datasource_name=None):
     return data_source
 
 
+# TODO consolidate all the myriad CLI tests into this
 def select_batch_kwargs_generator(context, datasource_name, available_data_assets_dict=None):
-    msg_prompt_select_generator = "Select batch kwarggenerator"
+    msg_prompt_select_generator = "Select batch kwarg generator"
 
     if available_data_assets_dict is None:
         available_data_assets_dict = context.get_available_data_asset_names(datasource_names=datasource_name)
@@ -771,6 +744,7 @@ def select_batch_kwargs_generator(context, datasource_name, available_data_asset
 
 
 # TODO this method needs testing
+# TODO this method has different numbers of returned objects
 def get_batch_kwargs(context,
                      datasource_name=None,
                      batch_kwargs_generator_name=None,
@@ -843,140 +817,6 @@ def get_batch_kwargs(context,
     return (datasource_name, batch_kwargs_generator_name, generator_asset, batch_kwargs)
 
 
-def create_expectation_suite(
-    context,
-    datasource_name=None,
-    batch_kwargs_generator_name=None,
-    generator_asset=None,
-    batch_kwargs=None,
-    expectation_suite_name=None,
-    additional_batch_kwargs=None,
-    empty_suite=False,
-    show_intro_message=False,
-    open_docs=False
-):
-    """
-    Create a new expectation suite.
-
-    :return: a tuple: (success, suite name)
-    """
-
-    msg_intro = "\n<cyan>========== Create sample Expectations ==========</cyan>\n\n"
-    msg_some_data_assets_not_found = """Some of the data assets you specified were not found: {0:s}    
-    """
-    msg_prompt_what_will_profiler_do = """
-Great Expectations will choose a couple of columns and generate expectations about them
-to demonstrate some examples of assertions you can make about your data. 
-    
-Press Enter to continue
-"""
-
-    msg_prompt_expectation_suite_name = """
-Name the new expectation suite"""
-
-    msg_suite_already_exists = "<red>An expectation suite named `{}` already exists. If you intend to edit the suite please use `great_expectations suite edit {}`.</red>"
-
-    if show_intro_message and not empty_suite:
-        cli_message(msg_intro)
-
-    data_source = select_datasource(context, datasource_name=datasource_name)
-    if data_source is None:
-        # select_datasource takes care of displaying an error message, so all is left here is to exit.
-        sys.exit(1)
-
-    datasource_name = data_source.name
-
-    existing_suite_names = [expectation_suite_id.expectation_suite_name for expectation_suite_id in context.list_expectation_suites()]
-
-    if expectation_suite_name in existing_suite_names:
-        cli_message(
-            msg_suite_already_exists.format(
-                expectation_suite_name,
-                expectation_suite_name
-            )
-        )
-        sys.exit(1)
-
-    if batch_kwargs_generator_name is None or generator_asset is None or batch_kwargs is None:
-        datasource_name, batch_kwargs_generator_name, generator_asset, batch_kwargs = get_batch_kwargs(
-            context,
-            datasource_name=datasource_name,
-            batch_kwargs_generator_name=batch_kwargs_generator_name,
-            generator_asset=generator_asset,
-            additional_batch_kwargs=additional_batch_kwargs)
-        # In this case, we have "consumed" the additional_batch_kwargs
-        additional_batch_kwargs = {}
-
-    if expectation_suite_name is None:
-        if generator_asset:
-            default_expectation_suite_name = "{}.warning".format(generator_asset)
-        elif "query" in batch_kwargs:
-            default_expectation_suite_name = "query.warning"
-        elif "path" in batch_kwargs:
-            try:
-                # Try guessing a filename
-                filename = os.path.split(os.path.normpath(batch_kwargs["path"]))[1]
-                # Take all but the last part after the period
-                filename = ".".join(filename.split(".")[:-1])
-                default_expectation_suite_name = str(filename) + ".warning"
-            except (OSError, IndexError):
-                default_expectation_suite_name = "warning"
-        else:
-            default_expectation_suite_name = "warning"
-        while True:
-            expectation_suite_name = click.prompt(msg_prompt_expectation_suite_name, default=default_expectation_suite_name, show_default=True)
-            if expectation_suite_name in existing_suite_names:
-                cli_message(
-                    msg_suite_already_exists.format(
-                        expectation_suite_name,
-                        expectation_suite_name
-                    )
-                )
-            else:
-                break
-
-    if empty_suite:
-        suite = context.create_expectation_suite(expectation_suite_name, overwrite_existing=False)
-        suite.add_citation(comment="New suite added via CLI", batch_kwargs=batch_kwargs)
-        context.save_expectation_suite(suite, expectation_suite_name)
-        return True, expectation_suite_name
-
-    click.prompt(msg_prompt_what_will_profiler_do, default=True, show_default=False)
-
-    cli_message("\nGenerating example Expectation Suite...")
-    run_id = datetime.datetime.utcnow().strftime("%Y%m%dT%H%M%S.%fZ")
-
-    profiling_results = context.profile_data_asset(
-        datasource_name,
-        batch_kwargs_generator_name=batch_kwargs_generator_name,
-        data_asset_name=generator_asset,
-        batch_kwargs=batch_kwargs,
-        profiler=BasicSuiteBuilderProfiler,
-        profiler_configuration="demo",
-        expectation_suite_name=expectation_suite_name,
-        run_id=run_id,
-        additional_batch_kwargs=additional_batch_kwargs
-    )
-
-    if profiling_results['success']:
-        build_docs(context, view=False)
-        if open_docs:  # This is mostly to keep tests from spawning windows
-            try:
-                # TODO this is really brittle and not covered in tests
-                validation_result = profiling_results["results"][0][1]
-                validation_result_identifier = ValidationResultIdentifier.from_object(validation_result)
-                context.open_data_docs(resource_identifier=validation_result_identifier)
-            except (KeyError, IndexError):
-                context.open_data_docs()
-
-        return True, expectation_suite_name
-
-    if profiling_results['error']['code'] == DataContext.PROFILING_ERROR_CODE_SPECIFIED_DATA_ASSETS_NOT_FOUND:
-        raise ge_exceptions.DataContextError(msg_some_data_assets_not_found.format(",".join(profiling_results['error']['not_found_data_assets'])))
-    if not profiling_results['success']:  # unknown error
-        raise ge_exceptions.DataContextError("Unknown profiling error code: " + profiling_results['error']['code'])
-
-
 def _get_batch_kwargs_from_generator_or_from_file_path(context, datasource_name,
                                                        batch_kwargs_generator_name=None,
                                                        additional_batch_kwargs={}):
@@ -1386,17 +1226,6 @@ Which database backend are you using?
 {}
 """.format("\n".join(["    {}. {}".format(i, db.value) for i, db in enumerate(SupportedDatabases, 1)]))
 
-#     msg_prompt_dbt_choose_profile = """
-# Please specify the name of the dbt profile (from your ~/.dbt/profiles.yml file Great Expectations \
-# should use to connect to the database
-#     """
-
-#     msg_dbt_go_to_notebook = """
-# To create expectations for your dbt models start Jupyter and open notebook
-# great_expectations/notebooks/using_great_expectations_with_dbt.ipynb -
-# it will walk you through next steps.
-#     """
-
 msg_prompt_filesys_enter_base_path = """
 Enter the path (relative or absolute) of the root directory where the data files are stored.
 """
