@@ -1,24 +1,35 @@
 import json
 import os
-import subprocess
 import sys
 
 import click
 
-from great_expectations import DataContext
+from great_expectations.cli import toolkit as toolkit
 from great_expectations import exceptions as ge_exceptions
-from great_expectations.cli.datasource import (
-    create_expectation_suite as create_expectation_suite_impl,
-)
 from great_expectations.cli.datasource import (
     get_batch_kwargs,
     select_datasource,
 )
-from great_expectations.cli.util import cli_message, load_expectation_suite, cli_message_list
-from great_expectations.core.usage_statistics.usage_statistics import send_usage_message, _anonymizers, \
-    edit_expectation_suite_usage_statistics
-from great_expectations.data_asset import DataAsset
-from great_expectations.render.renderer.suite_edit_notebook_renderer import SuiteEditNotebookRenderer
+from great_expectations.cli.mark import Mark as mark
+from great_expectations.cli.toolkit import (
+    create_expectation_suite as create_expectation_suite_impl,
+)
+from great_expectations.cli.util import (
+    cli_message,
+    cli_message_list,
+    load_data_context_with_error_handling,
+    load_expectation_suite,
+)
+from great_expectations.core.usage_statistics.usage_statistics import (
+    edit_expectation_suite_usage_statistics,
+    send_usage_message,
+)
+from great_expectations.render.renderer.suite_edit_notebook_renderer import (
+    SuiteEditNotebookRenderer,
+)
+from great_expectations.render.renderer.suite_scaffold_notebook_renderer import (
+    SuiteScaffoldNotebookRenderer,
+)
 
 json_parse_exception = json.decoder.JSONDecodeError
 
@@ -77,17 +88,20 @@ def suite_edit(suite, datasource, directory, jupyter, batch_kwargs):
 
     Read more about specifying batches of data in the documentation: https://docs.greatexpectations.io/
     """
-    _suite_edit(suite, datasource, directory, jupyter, batch_kwargs)
+    _suite_edit(
+        suite,
+        datasource,
+        directory,
+        jupyter,
+        batch_kwargs,
+        usage_event="cli.suite.edit",
+    )
 
 
-def _suite_edit(suite, datasource, directory, jupyter, batch_kwargs):
+def _suite_edit(suite, datasource, directory, jupyter, batch_kwargs, usage_event):
     batch_kwargs_json = batch_kwargs
     batch_kwargs = None
-    try:
-        context = DataContext(directory)
-    except ge_exceptions.ConfigNotFoundError as err:
-        cli_message("<red>{}</red>".format(err.message))
-        return
+    context = load_data_context_with_error_handling(directory)
 
     try:
         suite = load_expectation_suite(context, suite)
@@ -98,8 +112,7 @@ def _suite_edit(suite, datasource, directory, jupyter, batch_kwargs):
                 batch_kwargs = json.loads(batch_kwargs_json)
                 if datasource:
                     batch_kwargs["datasource"] = datasource
-                _batch = context.get_batch(batch_kwargs, suite.expectation_suite_name)
-                assert isinstance(_batch, DataAsset)
+                _batch = toolkit.load_batch(context, suite, batch_kwargs)
             except json_parse_exception as je:
                 cli_message(
                     "<red>Please check that your batch_kwargs are valid JSON.\n{}</red>".format(
@@ -107,9 +120,7 @@ def _suite_edit(suite, datasource, directory, jupyter, batch_kwargs):
                     )
                 )
                 send_usage_message(
-                    data_context=context,
-                    event="cli.suite.edit",
-                    success=False
+                    data_context=context, event=usage_event, success=False
                 )
                 sys.exit(1)
             except ge_exceptions.DataContextError:
@@ -117,9 +128,7 @@ def _suite_edit(suite, datasource, directory, jupyter, batch_kwargs):
                     "<red>Please check that your batch_kwargs are able to load a batch.</red>"
                 )
                 send_usage_message(
-                    data_context=context,
-                    event="cli.suite.edit",
-                    success=False
+                    data_context=context, event=usage_event, success=False
                 )
                 sys.exit(1)
             except ValueError as ve:
@@ -129,9 +138,7 @@ def _suite_edit(suite, datasource, directory, jupyter, batch_kwargs):
                     )
                 )
                 send_usage_message(
-                    data_context=context,
-                    event="cli.suite.edit",
-                    success=False
+                    data_context=context, event=usage_event, success=False
                 )
                 sys.exit(1)
         elif citations:
@@ -140,7 +147,7 @@ def _suite_edit(suite, datasource, directory, jupyter, batch_kwargs):
 
         if not batch_kwargs:
             cli_message(
-            """
+                """
 A batch of data is required to edit the suite - let's help you to specify it."""
             )
 
@@ -150,18 +157,14 @@ A batch of data is required to edit the suite - let's help you to specify it."""
             except ValueError as ve:
                 cli_message("<red>{}</red>".format(ve))
                 send_usage_message(
-                    data_context=context,
-                    event="cli.suite.edit",
-                    success=False
+                    data_context=context, event=usage_event, success=False
                 )
                 sys.exit(1)
 
             if not data_source:
                 cli_message("<red>No datasources found in the context.</red>")
                 send_usage_message(
-                    data_context=context,
-                    event="cli.suite.edit",
-                    success=False
+                    data_context=context, event=usage_event, success=False
                 )
                 sys.exit(1)
 
@@ -179,41 +182,64 @@ A batch of data is required to edit the suite - let's help you to specify it."""
                     additional_batch_kwargs=additional_batch_kwargs,
                 )
 
-        notebook_name = "{}.ipynb".format(suite.expectation_suite_name)
-
-        notebook_path = os.path.join(
-            context.root_directory, context.GE_EDIT_NOTEBOOK_DIR, notebook_name
-        )
+        notebook_name = "edit_{}.ipynb".format(suite.expectation_suite_name)
+        notebook_path = _get_notebook_path(context, notebook_name)
         SuiteEditNotebookRenderer().render_to_disk(suite, notebook_path, batch_kwargs)
 
         if not jupyter:
-            cli_message("To continue editing this suite, run <green>jupyter "
-                        f"notebook {notebook_path}</green>")
+            cli_message(
+                f"To continue editing this suite, run <green>jupyter notebook {notebook_path}</green>"
+            )
 
         payload = edit_expectation_suite_usage_statistics(
-            data_context=context,
-            expectation_suite_name=suite.expectation_suite_name
+            data_context=context, expectation_suite_name=suite.expectation_suite_name
         )
 
         send_usage_message(
-            data_context=context,
-            event="cli.suite.edit",
-            event_payload=payload,
-            success=True
+            data_context=context, event=usage_event, event_payload=payload, success=True
         )
 
         if jupyter:
-            subprocess.call(["jupyter", "notebook", notebook_path])
+            toolkit.launch_jupyter_notebook(notebook_path)
 
     except Exception as e:
-        send_usage_message(
-            data_context=context,
-            event="cli.suite.edit",
-            success=False
-        )
+        send_usage_message(data_context=context, event=usage_event, success=False)
         raise e
 
 
+@suite.command(name="demo")
+@click.option("--suite", "-es", default=None, help="Expectation suite name.")
+@click.option(
+    "--directory",
+    "-d",
+    default=None,
+    help="The project's great_expectations directory.",
+)
+@click.option(
+    "--view/--no-view",
+    help="By default open in browser unless you specify the --no-view flag",
+    default=True,
+)
+@mark.cli_as_beta
+def suite_demo(suite, directory, view):
+    """
+    Create a new demo Expectation Suite.
+
+    Great Expectations will choose a couple of columns and generate expectations
+    about them to demonstrate some examples of assertions you can make about
+    your data.
+    """
+    _suite_new(
+        suite=suite,
+        directory=directory,
+        empty=False,
+        jupyter=False,
+        view=view,
+        batch_kwargs=None,
+        usage_event="cli.suite.demo",
+    )
+
+
 @suite.command(name="new")
 @click.option("--suite", "-es", default=None, help="Expectation suite name.")
 @click.option("--empty", "empty", flag_value=True, help="Create an empty suite.")
@@ -239,7 +265,16 @@ A batch of data is required to edit the suite - let's help you to specify it."""
     default=None,
     help="Additional keyword arguments to be provided to get_batch when loading the data asset. Must be a valid JSON dictionary",
 )
+@mark.cli_as_deprecation(
+    """<yellow>In the next major release:
+  - `suite new` will create an empty suite and will no longer have the --empty flag
+  - `suite new` will no longer have a --view/no-view flag. Data Docs will not be opened.
+  - The current behavior of creating a demo suite will transition to the new command `suite demo` which can be used now.
+  - We also suggest using the `suite scaffold` command for faster suite creation.
+</yellow>"""
+)
 def suite_new(suite, directory, empty, jupyter, view, batch_kwargs):
+    # TODO update docstring on next major release
     """
     Create a new Expectation Suite.
 
@@ -248,11 +283,20 @@ def suite_new(suite, directory, empty, jupyter, view, batch_kwargs):
 
     If you wish to skip the examples, add the `--empty` flag.
     """
-    try:
-        context = DataContext(directory)
-    except ge_exceptions.ConfigNotFoundError as err:
-        cli_message("<red>{}</red>".format(err.message))
-        return
+    _suite_new(
+        suite=suite,
+        directory=directory,
+        empty=empty,
+        jupyter=jupyter,
+        view=view,
+        batch_kwargs=batch_kwargs,
+        usage_event="cli.suite.new",
+    )
+
+
+def _suite_new(suite: str, directory: str, empty: bool, jupyter: bool, view: bool, batch_kwargs, usage_event: str) -> None:
+    # TODO break this up into demo and new
+    context = load_data_context_with_error_handling(directory)
 
     datasource_name = None
     generator_name = None
@@ -282,20 +326,21 @@ def suite_new(suite, directory, empty, jupyter, view, batch_kwargs):
             )
             if empty:
                 if jupyter:
-                    cli_message("""<green>Because you requested an empty suite, we'll open a notebook for you now to edit it!
-If you wish to avoid this you can add the `--no-jupyter` flag.</green>\n\n""")
-                _suite_edit(suite_name, datasource_name, directory, jupyter=jupyter, batch_kwargs=batch_kwargs)
-            send_usage_message(
-                data_context=context,
-                event="cli.suite.new",
-                success=True
+                    cli_message(
+                        """<green>Because you requested an empty suite, we'll open a notebook for you now to edit it!
+If you wish to avoid this you can add the `--no-jupyter` flag.</green>\n\n"""
+                    )
+            _suite_edit(
+                suite_name,
+                datasource_name,
+                directory,
+                jupyter=jupyter,
+                batch_kwargs=batch_kwargs,
+                usage_event=usage_event,
             )
+            send_usage_message(data_context=context, event=usage_event, success=True)
         else:
-            send_usage_message(
-                data_context=context,
-                event="cli.suite.new",
-                success=False
-            )
+            send_usage_message(data_context=context, event=usage_event, success=False)
     except (
         ge_exceptions.DataContextError,
         ge_exceptions.ProfilerError,
@@ -303,21 +348,69 @@ If you wish to avoid this you can add the `--no-jupyter` flag.</green>\n\n""")
         SQLAlchemyError,
     ) as e:
         cli_message("<red>{}</red>".format(e))
-        send_usage_message(
-            data_context=context,
-            event="cli.suite.new",
-            success=False
-        )
+        send_usage_message(data_context=context, event=usage_event, success=False)
         sys.exit(1)
     except Exception as e:
-        send_usage_message(
-            data_context=context,
-            event="cli.suite.new",
-            success=False
-        )
+        send_usage_message(data_context=context, event=usage_event, success=False)
         raise e
 
 
+@suite.command(name="scaffold")
+@click.argument("suite")
+@click.option(
+    "--directory",
+    "-d",
+    default=None,
+    help="The project's great_expectations directory.",
+)
+@click.option(
+    "--jupyter/--no-jupyter",
+    is_flag=True,
+    help="By default launch jupyter notebooks unless you specify the --no-jupyter flag",
+    default=True,
+)
+@mark.cli_as_experimental
+def suite_scaffold(suite, directory, jupyter):
+    """Scaffold a new Expectation Suite."""
+    _suite_scaffold(suite, directory, jupyter)
+
+
+def _suite_scaffold(suite: str, directory: str, jupyter: bool) -> None:
+    usage_event = "cli.suite.scaffold"
+    suite_name = suite
+    context = load_data_context_with_error_handling(directory)
+    notebook_filename = f"scaffold_{suite_name}.ipynb"
+    notebook_path = _get_notebook_path(context, notebook_filename)
+
+    if suite_name in context.list_expectation_suite_names():
+        toolkit.tell_user_suite_exists(suite_name)
+        if os.path.isfile(notebook_path):
+            cli_message(
+                f"  - If you wish to adjust your scaffolding, you can open this notebook with jupyter: `{notebook_path}` <red>(Please note that if you run that notebook, you will overwrite your existing suite.)</red>"
+            )
+        send_usage_message(data_context=context, event=usage_event, success=False)
+        sys.exit(1)
+
+    datasource = toolkit.select_datasource(context)
+    if datasource is None:
+        send_usage_message(data_context=context, event=usage_event, success=False)
+        sys.exit(1)
+
+    _suite = context.create_expectation_suite(suite_name)
+    _, _, _, batch_kwargs = get_batch_kwargs(context, datasource_name=datasource.name)
+    renderer = SuiteScaffoldNotebookRenderer(context, _suite, batch_kwargs)
+    renderer.render_to_disk(notebook_path)
+
+    if jupyter:
+        toolkit.launch_jupyter_notebook(notebook_path)
+    else:
+        cli_message(
+            f"To continue scaffolding this suite, run `jupyter notebook {notebook_path}`"
+        )
+
+    send_usage_message(data_context=context, event=usage_event, success=True)
+
+
 @suite.command(name="list")
 @click.option(
     "--directory",
@@ -327,11 +420,7 @@ If you wish to avoid this you can add the `--no-jupyter` flag.</green>\n\n""")
 )
 def suite_list(directory):
     """Lists available Expectation Suites."""
-    try:
-        context = DataContext(directory)
-    except ge_exceptions.ConfigNotFoundError as err:
-        cli_message("<red>{}</red>".format(err.message))
-        return
+    context = load_data_context_with_error_handling(directory)
 
     try:
         suite_names = [
@@ -341,9 +430,7 @@ def suite_list(directory):
         if len(suite_names) == 0:
             cli_message("No Expectation Suites found")
             send_usage_message(
-                data_context=context,
-                event="cli.suite.list",
-                success=True
+                data_context=context, event="cli.suite.list", success=True
             )
             return
 
@@ -354,15 +441,15 @@ def suite_list(directory):
             list_intro_string = "{} Expectation Suites found:".format(len(suite_names))
 
         cli_message_list(suite_names, list_intro_string)
-        send_usage_message(
-            data_context=context,
-            event="cli.suite.list",
-            success=True
-        )
+        send_usage_message(data_context=context, event="cli.suite.list", success=True)
     except Exception as e:
-        send_usage_message(
-            data_context=context,
-            event="cli.suite.list",
-            success=False
+        send_usage_message(data_context=context, event="cli.suite.list", success=False)
+        raise e
+
+
+def _get_notebook_path(context, notebook_name):
+    return os.path.abspath(
+        os.path.join(
+            context.root_directory, context.GE_EDIT_NOTEBOOK_DIR, notebook_name
         )
-        raise e
\ No newline at end of file
+    )
