@@ -3,14 +3,19 @@ import sys
 
 import click
 
-from great_expectations import DataContext
-from great_expectations import exceptions as ge_exceptions
 from great_expectations.cli.datasource import (
     get_batch_kwargs,
     select_datasource,
 )
-from great_expectations.cli.util import cli_message, load_expectation_suite
-from great_expectations.core.usage_statistics.usage_statistics import send_usage_message
+from great_expectations.cli.util import (
+    cli_message,
+    load_data_context_with_error_handling,
+    load_expectation_suite,
+)
+from great_expectations.cli.mark import Mark as mark
+from great_expectations.core.usage_statistics.usage_statistics import (
+    send_usage_message,
+)
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.util import lint_code
 
@@ -31,10 +36,10 @@ def tap():
     default=None,
     help="The project's great_expectations directory.",
 )
+@mark.cli_as_experimental
 def tap_new(suite, tap_filename, directory, datasource=None):
-    """BETA! Create a new tap file for easy deployments."""
-    cli_message("<yellow>This is a BETA feature which may change. If you have ideas please file a GitHub issue!</yellow>")
-    context = _get_context(directory)
+    """Create a new tap file for easy deployments. (BETA)"""
+    context = load_data_context_with_error_handling(directory)
     try:
         _validate_tap_filename(tap_filename)
         context_directory = context.root_directory
@@ -73,15 +78,6 @@ def _validate_tap_filename(tap_filename):
         exit(1)
 
 
-def _get_context(directory):
-    try:
-        context = DataContext(directory)
-    except ge_exceptions.ConfigNotFoundError as err:
-        cli_message("<red>{}</red>".format(err.message))
-        exit(1)
-    return context
-
-
 def _get_datasource(context, datasource):
     datasource = select_datasource(context, datasource_name=datasource)
     if not datasource:
